#[repr(transparent)]pub struct SzFlags(<SzFlags as PublicFlags>::Internal);Expand description
Bitflags for controlling Senzing SDK operations
These flags match the C# SDK SzFlag enum exactly. For detailed flag descriptions and usage patterns, see the official documentation: https://www.senzing.com/docs/flags/4/
Tuple Fields
0: <SzFlags as PublicFlags>::InternalImplementations
Sourceimpl SzFlags
impl SzFlags
pub const EXPORT_INCLUDE_MULTI_RECORD_ENTITIES: Self
pub const EXPORT_INCLUDE_POSSIBLY_SAME: Self
pub const EXPORT_INCLUDE_POSSIBLY_RELATED: Self
pub const EXPORT_INCLUDE_NAME_ONLY: Self
pub const EXPORT_INCLUDE_DISCLOSED: Self
pub const EXPORT_INCLUDE_SINGLE_RECORD_ENTITIES: Self
pub const ENTITY_INCLUDE_POSSIBLY_SAME_RELATIONS: Self
pub const ENTITY_INCLUDE_POSSIBLY_RELATED_RELATIONS: Self
pub const ENTITY_INCLUDE_NAME_ONLY_RELATIONS: Self
pub const ENTITY_INCLUDE_DISCLOSED_RELATIONS: Self
pub const ENTITY_INCLUDE_ALL_FEATURES: Self
pub const ENTITY_INCLUDE_REPRESENTATIVE_FEATURES: Self
pub const ENTITY_INCLUDE_ENTITY_NAME: Self
pub const ENTITY_INCLUDE_RECORD_SUMMARY: Self
pub const ENTITY_INCLUDE_RECORD_DATA: Self
pub const ENTITY_INCLUDE_RECORD_MATCHING_INFO: Self
pub const ENTITY_INCLUDE_RECORD_JSON_DATA: Self
pub const ENTITY_INCLUDE_RECORD_FEATURES: Self
pub const ENTITY_INCLUDE_RELATED_ENTITY_NAME: Self
pub const ENTITY_INCLUDE_RELATED_MATCHING_INFO: Self
pub const ENTITY_INCLUDE_RELATED_RECORD_SUMMARY: Self
pub const ENTITY_INCLUDE_RELATED_RECORD_DATA: Self
pub const ENTITY_INCLUDE_INTERNAL_FEATURES: Self
pub const ENTITY_INCLUDE_FEATURE_STATS: Self
pub const FIND_PATH_STRICT_AVOID: Self
pub const FIND_PATH_INCLUDE_MATCHING_INFO: Self
pub const INCLUDE_FEATURE_SCORES: Self
pub const SEARCH_INCLUDE_STATS: Self
pub const ENTITY_INCLUDE_RECORD_TYPES: Self
pub const ENTITY_INCLUDE_RELATED_RECORD_TYPES: Self
pub const ENTITY_INCLUDE_RECORD_UNMAPPED_DATA: Self
pub const ENTITY_INCLUDE_RECORD_FEATURE_DETAILS: Self
pub const ENTITY_INCLUDE_RECORD_FEATURE_STATS: Self
pub const ENTITY_INCLUDE_RECORD_DATES: Self
pub const SEARCH_INCLUDE_ALL_CANDIDATES: Self
pub const FIND_NETWORK_INCLUDE_MATCHING_INFO: Self
pub const INCLUDE_MATCH_KEY_DETAILS: Self
pub const SEARCH_INCLUDE_REQUEST: Self
pub const SEARCH_INCLUDE_REQUEST_DETAILS: Self
pub const WITH_INFO: Self
pub const SEARCH_INCLUDE_RESOLVED: Self
pub const SEARCH_INCLUDE_POSSIBLY_SAME: Self
pub const SEARCH_INCLUDE_POSSIBLY_RELATED: Self
pub const SEARCH_INCLUDE_NAME_ONLY: Self
pub const EXPORT_INCLUDE_ALL_ENTITIES: Self
pub const EXPORT_INCLUDE_ALL_HAVING_RELATIONSHIPS: Self
pub const ENTITY_INCLUDE_ALL_RELATIONS: Self
pub const SEARCH_INCLUDE_ALL_ENTITIES: Self
pub const RECORD_ALL_FLAGS: Self
pub const RECORD_PREVIEW_ALL_FLAGS: Self
pub const ENTITY_CORE_FLAGS: Self
Sourceimpl SzFlags
impl SzFlags
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SzFlags
impl SzFlags
Sourcepub const fn iter(&self) -> Iter<SzFlags>
pub const fn iter(&self) -> Iter<SzFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SzFlags>
pub const fn iter_names(&self) -> IterNames<SzFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl SzFlags
impl SzFlags
Sourcepub const RECORD_DEFAULT_FLAGS: SzFlags = SzFlags::ENTITY_INCLUDE_RECORD_JSON_DATA
pub const RECORD_DEFAULT_FLAGS: SzFlags = SzFlags::ENTITY_INCLUDE_RECORD_JSON_DATA
Default flags for record operations
Sourcepub const RECORD_PREVIEW_DEFAULT_FLAGS: SzFlags = SzFlags::ENTITY_INCLUDE_RECORD_FEATURE_DETAILS
pub const RECORD_PREVIEW_DEFAULT_FLAGS: SzFlags = SzFlags::ENTITY_INCLUDE_RECORD_FEATURE_DETAILS
Default flags for record preview operations
Sourcepub const ENTITY_DEFAULT_FLAGS: SzFlags
pub const ENTITY_DEFAULT_FLAGS: SzFlags
Default flags for entity operations
Sourcepub const ENTITY_BRIEF_DEFAULT_FLAGS: SzFlags
pub const ENTITY_BRIEF_DEFAULT_FLAGS: SzFlags
Brief default flags for entity operations
Sourcepub const EXPORT_DEFAULT_FLAGS: SzFlags
pub const EXPORT_DEFAULT_FLAGS: SzFlags
Default flags for export operations
Sourcepub const FIND_PATH_DEFAULT_FLAGS: SzFlags
pub const FIND_PATH_DEFAULT_FLAGS: SzFlags
Default flags for find path operations
Sourcepub const FIND_NETWORK_DEFAULT_FLAGS: SzFlags
pub const FIND_NETWORK_DEFAULT_FLAGS: SzFlags
Default flags for find network operations
Sourcepub const SEARCH_BY_ATTRIBUTES_ALL: SzFlags
pub const SEARCH_BY_ATTRIBUTES_ALL: SzFlags
All search by attributes flags
Sourcepub const SEARCH_BY_ATTRIBUTES_STRONG: SzFlags
pub const SEARCH_BY_ATTRIBUTES_STRONG: SzFlags
Strong search by attributes flags
Sourcepub const SEARCH_BY_ATTRIBUTES_MINIMAL_ALL: SzFlags
pub const SEARCH_BY_ATTRIBUTES_MINIMAL_ALL: SzFlags
Minimal all search by attributes flags
Sourcepub const SEARCH_BY_ATTRIBUTES_MINIMAL_STRONG: SzFlags
pub const SEARCH_BY_ATTRIBUTES_MINIMAL_STRONG: SzFlags
Minimal strong search by attributes flags
Sourcepub const SEARCH_BY_ATTRIBUTES_DEFAULT_FLAGS: SzFlags = Self::SEARCH_BY_ATTRIBUTES_ALL
pub const SEARCH_BY_ATTRIBUTES_DEFAULT_FLAGS: SzFlags = Self::SEARCH_BY_ATTRIBUTES_ALL
Default flags for search by attributes operations
Sourcepub const WHY_ENTITIES_DEFAULT_FLAGS: SzFlags = SzFlags::INCLUDE_FEATURE_SCORES
pub const WHY_ENTITIES_DEFAULT_FLAGS: SzFlags = SzFlags::INCLUDE_FEATURE_SCORES
Default flags for why entities operations
Sourcepub const WHY_RECORDS_DEFAULT_FLAGS: SzFlags = SzFlags::INCLUDE_FEATURE_SCORES
pub const WHY_RECORDS_DEFAULT_FLAGS: SzFlags = SzFlags::INCLUDE_FEATURE_SCORES
Default flags for why records operations
Sourcepub const WHY_RECORD_IN_ENTITY_DEFAULT_FLAGS: SzFlags = SzFlags::INCLUDE_FEATURE_SCORES
pub const WHY_RECORD_IN_ENTITY_DEFAULT_FLAGS: SzFlags = SzFlags::INCLUDE_FEATURE_SCORES
Default flags for why record in entity operations
Sourcepub const WHY_SEARCH_DEFAULT_FLAGS: SzFlags
pub const WHY_SEARCH_DEFAULT_FLAGS: SzFlags
Default flags for why search operations
Sourcepub const HOW_ENTITY_DEFAULT_FLAGS: SzFlags = SzFlags::INCLUDE_FEATURE_SCORES
pub const HOW_ENTITY_DEFAULT_FLAGS: SzFlags = SzFlags::INCLUDE_FEATURE_SCORES
Default flags for how entity operations
Sourcepub const HOW_ALL_FLAGS: SzFlags
pub const HOW_ALL_FLAGS: SzFlags
All flags for how entity operations
Sourcepub const VIRTUAL_ENTITY_DEFAULT_FLAGS: SzFlags = SzFlags::ENTITY_CORE_FLAGS
pub const VIRTUAL_ENTITY_DEFAULT_FLAGS: SzFlags = SzFlags::ENTITY_CORE_FLAGS
Default flags for virtual entity operations
Sourcepub const VIRTUAL_ENTITY_ALL_FLAGS: SzFlags
pub const VIRTUAL_ENTITY_ALL_FLAGS: SzFlags
All flags for virtual entity operations
Sourcepub const ADD_RECORD_DEFAULT_FLAGS: SzFlags
pub const ADD_RECORD_DEFAULT_FLAGS: SzFlags
Default flags for adding records
Sourcepub const ADD_RECORD_ALL_FLAGS: SzFlags = SzFlags::WITH_INFO
pub const ADD_RECORD_ALL_FLAGS: SzFlags = SzFlags::WITH_INFO
All flags for adding records (with info)
Sourcepub const DELETE_RECORD_DEFAULT_FLAGS: SzFlags
pub const DELETE_RECORD_DEFAULT_FLAGS: SzFlags
Default flags for deleting records
Sourcepub const DELETE_RECORD_ALL_FLAGS: SzFlags = SzFlags::WITH_INFO
pub const DELETE_RECORD_ALL_FLAGS: SzFlags = SzFlags::WITH_INFO
All flags for deleting records (with info)
Sourcepub const REEVALUATE_RECORD_DEFAULT_FLAGS: SzFlags
pub const REEVALUATE_RECORD_DEFAULT_FLAGS: SzFlags
Default flags for reevaluating records
Sourcepub const REEVALUATE_RECORD_ALL_FLAGS: SzFlags = SzFlags::WITH_INFO
pub const REEVALUATE_RECORD_ALL_FLAGS: SzFlags = SzFlags::WITH_INFO
All flags for reevaluating records (with info)
Sourcepub const REEVALUATE_ENTITY_DEFAULT_FLAGS: SzFlags
pub const REEVALUATE_ENTITY_DEFAULT_FLAGS: SzFlags
Default flags for reevaluating entities
Sourcepub const REEVALUATE_ENTITY_ALL_FLAGS: SzFlags = SzFlags::WITH_INFO
pub const REEVALUATE_ENTITY_ALL_FLAGS: SzFlags = SzFlags::WITH_INFO
All flags for reevaluating entities (with info)
Sourcepub const REDO_DEFAULT_FLAGS: SzFlags
pub const REDO_DEFAULT_FLAGS: SzFlags
Default flags for redo operations
Sourcepub const REDO_ALL_FLAGS: SzFlags = SzFlags::WITH_INFO
pub const REDO_ALL_FLAGS: SzFlags = SzFlags::WITH_INFO
All flags for redo operations (with info)
Sourcepub const FIND_INTERESTING_ENTITIES_DEFAULT_FLAGS: SzFlags
pub const FIND_INTERESTING_ENTITIES_DEFAULT_FLAGS: SzFlags
Default flags for find interesting entities operations
Sourcepub const FIND_INTERESTING_ENTITIES_ALL_FLAGS: SzFlags
pub const FIND_INTERESTING_ENTITIES_ALL_FLAGS: SzFlags
All flags for find interesting entities operations